==> haskell-trifecta-2.1.4-167.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-G90Tb8ST4Q3KlNDtRZOYku
key:                  trifecta-2.1.4-G90Tb8ST4Q3KlNDtRZOYku
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  770cb2428da7d684f912b45c92cb2fa2
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-G90Tb8ST4Q3KlNDtRZOYku
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt array-0.5.6.0
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj
    blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8 bytestring-0.11.5.3
    charset-0.3.12-AmjtFvhjrx2JD02c7IN6qm
    comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    deepseq-1.4.8.1 fingertree-0.1.6.2-1PgNfRTFIgw8zTTFVYZdaB
    ghc-prim-0.10.0 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM mtl-2.3.1
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    reducers-3.12.5-AExear36UrA4z6wgWtct1l transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-2.1.4-168-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-4csqTbo6uTk9GcLisESMby
key:                  trifecta-2.1.4-4csqTbo6uTk9GcLisESMby
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  688ca3934ffe1116bfb08efad4012b30
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-4csqTbo6uTk9GcLisESMby
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9 bytestring-0.11.5.3
    charset-0.3.12-2D9nY7DBdxY1nhEyRK58pN
    comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    deepseq-1.4.8.1 fingertree-0.1.6.2-9C2f3k75hFcCEg0BQd5B9P
    ghc-prim-0.10.0 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB mtl-2.3.1
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    reducers-3.12.5-8ZhPkObIjbz4xpF2CpKfJ transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
